<?php

declare(strict_types=1);

return [
    "key" => env('INSTALL_KEY'),
    "required" => filter_var(env('INSTALL_REQUIRED', true), FILTER_VALIDATE_BOOL),
    "path" => env('INSTALL_PATH', 'install'),
];
